Exception: PumaPlus::Wire::PayloadTooLarge

Inherits:
StandardError
  • Object
show all
Defined in:
lib/puma_plus/wire.rb

Overview

Raised when a peer announces a frame larger than MAX_PAYLOAD. The only defense against a corrupt or hostile peer causing an OOM.